<?php
/**
 * Plugin Name: FeastieBar - Recipe Tools for Food Blogs
 * Plugin URI: http://www.feastie.com/goodies
 * Description: Link recipes on your food blog directly to the bookmarking and grocery shopping list tools at Feastie.
 * Version: 0.1
 * Author: Feastie
 * Author URI: http://www.feastie.com
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

/**
 * Add function to widgets_init that'll load our widget.
 * @since 0.1
 */
add_action( 'widgets_init', 'feastiebar_load_widgets' );

/**
 * Register our widget.
 * 
 * @since 0.1
 */
function feastiebar_load_widgets() {
	register_widget( 'FeastieBar_Widget' );
}

/**
 * FeastieBar Widget class.
 *
 * @since 0.1
 */
class FeastieBar_Widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function FeastieBar_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'feastiebar', 'description' => __('Link recipes on your food blog directly to the bookmarking and grocery shopping list tools at Feastie.', 'feastiebar') );

		/* Create the widget. */
		$this->WP_Widget( 'feastiebar-widget', __('FeastieBar Widget', 'feastiebar'), $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$size = $instance['size'];
		$layout = $instance['layout'];
		$show_link = isset( $instance['show_link'] ) ? $instance['show_link'] : false;

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

		/* The actual widget output */
		$output = '<script src="http://widgets.feastie.com/recipetools.js" type="text/javascript" data-size="' . $size . '" data-layout="' . $layout . '"></script>';

		if ( $show_link )
		  $output .= '<div style="font-size: 9px; font-family: Verdana, Arial, sans-serif; margin: 0; text-align: left; color=#666;">Proudly powered by <a href="http://www.feastie.com">Feastie</a></div>';

		echo $output;
	
		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );

		$instance['size'] = $new_instance['size'];
		$instance['layout'] = $new_instance['layout'];
		$instance['show_link'] = $new_instance['show_link'];

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('FeastieBar', 'feastiebar'), 'size' => 'large', 'layout' => 'vertical', 'show_link' => false);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'hybrid'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>


		<!-- Size: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'size' ); ?>"><?php _e('Size:', 'feastiebar'); ?></label> 
			<select id="<?php echo $this->get_field_id( 'size' ); ?>" name="<?php echo $this->get_field_name( 'size' ); ?>" class="widefat" style="width:100%;">
				<option <?php if ( 'large' == $instance['format'] ) echo 'selected="selected"'; ?>>large</option>
				<option <?php if ( 'medium' == $instance['format'] ) echo 'selected="selected"'; ?>>medium</option>
				<option <?php if ( 'small' == $instance['format'] ) echo 'selected="selected"'; ?>>small</option>
				<option <?php if ( 'tiny' == $instance['format'] ) echo 'selected="selected"'; ?>>tiny</option>
			</select>
		</p>


		<!-- Layout: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php _e('Layout:', 'feastiebar'); ?></label> 
			<select id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>" class="widefat" style="width:100%;">
				<option <?php if ( 'horizontal' == $instance['format'] ) echo 'selected="selected"'; ?>>horizontal</option>
				<option <?php if ( 'vertical' == $instance['format'] ) echo 'selected="selected"'; ?>>vertical</option>
			</select>
		</p>

		<!-- Show Link? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['show_link'], true ); ?> id="<?php echo $this->get_field_id( 'show_link' ); ?>" name="<?php echo $this->get_field_name( 'show_link' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_link' ); ?>"><?php _e('Display "Proudly Powered by Feastie"?', 'feastiebar'); ?></label>
		</p>



	<?php
	}
}

?>